==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/RFQPARTDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour RFQPARTDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQPARTDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDQTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQPROJECTBUDGET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQWORKORDERACTIVITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELADDRESSCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGCURRENCY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQPARTDETAILS_Type", propOrder = {
    "rfqlineid",
    "partid",
    "type",
    "requestedqty",
    "inspectionrequired",
    "byasset",
    "rfqprojectbudget",
    "rfqworkorderactivity",
    "relatedworkorderid",
    "equipmentid",
    "multiequip",
    "uomid",
    "duedate",
    "deladdresscode",
    "orgcurrency",
    "jobsequence"
})
public class RFQPARTDETAILS_Type {

    @XmlElement(name = "RFQLINEID", required = true)
    protected RFQLINEID_Type rfqlineid;
    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "TYPE")
    protected TYPE_Type type;
    @XmlElement(name = "REQUESTEDQTY", required = true)
    protected QUANTITY requestedqty;
    @XmlElement(name = "INSPECTIONREQUIRED")
    protected String inspectionrequired;
    @XmlElement(name = "BYASSET")
    protected String byasset;
    @XmlElement(name = "RFQPROJECTBUDGET")
    protected RFQPROJECTBUDGET_Type rfqprojectbudget;
    @XmlElement(name = "RFQWORKORDERACTIVITY")
    protected RFQWORKORDERACTIVITY rfqworkorderactivity;
    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "EQUIPMENTID")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "MULTIEQUIP")
    protected String multiequip;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "DUEDATE")
    protected DATETIME duedate;
    @XmlElement(name = "DELADDRESSCODE")
    protected String deladdresscode;
    @XmlElement(name = "ORGCURRENCY", required = true)
    protected CURRENCYID_Type orgcurrency;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;

    /**
     * Obtient la valeur de la propriété rfqlineid.
     * 
     * @return
     *     possible object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public RFQLINEID_Type getRFQLINEID() {
        return rfqlineid;
    }

    /**
     * Définit la valeur de la propriété rfqlineid.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public void setRFQLINEID(RFQLINEID_Type value) {
        this.rfqlineid = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété requestedqty.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREQUESTEDQTY() {
        return requestedqty;
    }

    /**
     * Définit la valeur de la propriété requestedqty.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREQUESTEDQTY(QUANTITY value) {
        this.requestedqty = value;
    }

    /**
     * Obtient la valeur de la propriété inspectionrequired.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONREQUIRED() {
        return inspectionrequired;
    }

    /**
     * Définit la valeur de la propriété inspectionrequired.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONREQUIRED(String value) {
        this.inspectionrequired = value;
    }

    /**
     * Obtient la valeur de la propriété byasset.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYASSET() {
        return byasset;
    }

    /**
     * Définit la valeur de la propriété byasset.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYASSET(String value) {
        this.byasset = value;
    }

    /**
     * Obtient la valeur de la propriété rfqprojectbudget.
     * 
     * @return
     *     possible object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public RFQPROJECTBUDGET_Type getRFQPROJECTBUDGET() {
        return rfqprojectbudget;
    }

    /**
     * Définit la valeur de la propriété rfqprojectbudget.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public void setRFQPROJECTBUDGET(RFQPROJECTBUDGET_Type value) {
        this.rfqprojectbudget = value;
    }

    /**
     * Obtient la valeur de la propriété rfqworkorderactivity.
     * 
     * @return
     *     possible object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public RFQWORKORDERACTIVITY getRFQWORKORDERACTIVITY() {
        return rfqworkorderactivity;
    }

    /**
     * Définit la valeur de la propriété rfqworkorderactivity.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public void setRFQWORKORDERACTIVITY(RFQWORKORDERACTIVITY value) {
        this.rfqworkorderactivity = value;
    }

    /**
     * Obtient la valeur de la propriété relatedworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Définit la valeur de la propriété relatedworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété multiequip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMULTIEQUIP() {
        return multiequip;
    }

    /**
     * Définit la valeur de la propriété multiequip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMULTIEQUIP(String value) {
        this.multiequip = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Obtient la valeur de la propriété duedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATE() {
        return duedate;
    }

    /**
     * Définit la valeur de la propriété duedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATE(DATETIME value) {
        this.duedate = value;
    }

    /**
     * Obtient la valeur de la propriété deladdresscode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDELADDRESSCODE() {
        return deladdresscode;
    }

    /**
     * Définit la valeur de la propriété deladdresscode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDELADDRESSCODE(String value) {
        this.deladdresscode = value;
    }

    /**
     * Obtient la valeur de la propriété orgcurrency.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getORGCURRENCY() {
        return orgcurrency;
    }

    /**
     * Définit la valeur de la propriété orgcurrency.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setORGCURRENCY(CURRENCYID_Type value) {
        this.orgcurrency = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/RFQPARTDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for RFQPARTDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQPARTDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REQUESTEDQTY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INSPECTIONREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BYASSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQPROJECTBUDGET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQWORKORDERACTIVITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELADDRESSCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGCURRENCY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQPARTDETAILS_Type", propOrder = {
    "rfqlineid",
    "partid",
    "type",
    "requestedqty",
    "inspectionrequired",
    "byasset",
    "rfqprojectbudget",
    "rfqworkorderactivity",
    "relatedworkorderid",
    "equipmentid",
    "multiequip",
    "uomid",
    "duedate",
    "deladdresscode",
    "orgcurrency",
    "jobsequence"
})
public class RFQPARTDETAILS_Type {

    @XmlElement(name = "RFQLINEID", required = true)
    protected RFQLINEID_Type rfqlineid;
    @XmlElement(name = "PARTID", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "TYPE")
    protected TYPE_Type type;
    @XmlElement(name = "REQUESTEDQTY", required = true)
    protected QUANTITY requestedqty;
    @XmlElement(name = "INSPECTIONREQUIRED")
    protected String inspectionrequired;
    @XmlElement(name = "BYASSET")
    protected String byasset;
    @XmlElement(name = "RFQPROJECTBUDGET")
    protected RFQPROJECTBUDGET_Type rfqprojectbudget;
    @XmlElement(name = "RFQWORKORDERACTIVITY")
    protected RFQWORKORDERACTIVITY rfqworkorderactivity;
    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "EQUIPMENTID")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "MULTIEQUIP")
    protected String multiequip;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "DUEDATE")
    protected DATETIME duedate;
    @XmlElement(name = "DELADDRESSCODE")
    protected String deladdresscode;
    @XmlElement(name = "ORGCURRENCY", required = true)
    protected CURRENCYID_Type orgcurrency;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;

    /**
     * Gets the value of the rfqlineid property.
     * 
     * @return
     *     possible object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public RFQLINEID_Type getRFQLINEID() {
        return rfqlineid;
    }

    /**
     * Sets the value of the rfqlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public void setRFQLINEID(RFQLINEID_Type value) {
        this.rfqlineid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the requestedqty property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREQUESTEDQTY() {
        return requestedqty;
    }

    /**
     * Sets the value of the requestedqty property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREQUESTEDQTY(QUANTITY value) {
        this.requestedqty = value;
    }

    /**
     * Gets the value of the inspectionrequired property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINSPECTIONREQUIRED() {
        return inspectionrequired;
    }

    /**
     * Sets the value of the inspectionrequired property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINSPECTIONREQUIRED(String value) {
        this.inspectionrequired = value;
    }

    /**
     * Gets the value of the byasset property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBYASSET() {
        return byasset;
    }

    /**
     * Sets the value of the byasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBYASSET(String value) {
        this.byasset = value;
    }

    /**
     * Gets the value of the rfqprojectbudget property.
     * 
     * @return
     *     possible object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public RFQPROJECTBUDGET_Type getRFQPROJECTBUDGET() {
        return rfqprojectbudget;
    }

    /**
     * Sets the value of the rfqprojectbudget property.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public void setRFQPROJECTBUDGET(RFQPROJECTBUDGET_Type value) {
        this.rfqprojectbudget = value;
    }

    /**
     * Gets the value of the rfqworkorderactivity property.
     * 
     * @return
     *     possible object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public RFQWORKORDERACTIVITY getRFQWORKORDERACTIVITY() {
        return rfqworkorderactivity;
    }

    /**
     * Sets the value of the rfqworkorderactivity property.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public void setRFQWORKORDERACTIVITY(RFQWORKORDERACTIVITY value) {
        this.rfqworkorderactivity = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the multiequip property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMULTIEQUIP() {
        return multiequip;
    }

    /**
     * Sets the value of the multiequip property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMULTIEQUIP(String value) {
        this.multiequip = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the duedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATE() {
        return duedate;
    }

    /**
     * Sets the value of the duedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATE(DATETIME value) {
        this.duedate = value;
    }

    /**
     * Gets the value of the deladdresscode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDELADDRESSCODE() {
        return deladdresscode;
    }

    /**
     * Sets the value of the deladdresscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDELADDRESSCODE(String value) {
        this.deladdresscode = value;
    }

    /**
     * Gets the value of the orgcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getORGCURRENCY() {
        return orgcurrency;
    }

    /**
     * Sets the value of the orgcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setORGCURRENCY(CURRENCYID_Type value) {
        this.orgcurrency = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

}
